# JD’s Guide to Visualization

Many people come into tulpamancy with different levels of visualization. It’s common for more artistic and imaginative people, as well as those with the tendency to daydream, to be able to visualize very well. However, some people find that they are very bad at visualizing, or even unable to visualize at all. The goal of this guide is to figure out your skill level of visualization, and to show you how to advance from there.

![I know what I should be seeing, but I can't see it](./jd-vis-1.png)

If you are experiencing this level of visualization, the most likely problem is that you are expecting to see your tulpa with your eyes, or see her image on the back of your eyelids. However, this is not the case. Visualization takes place in the mind's eye, that is in an area separate from the stream of data from the eyes to the brain. You'll want to focus on adjusting your attention away from your physical eyes, and instead to your mind's eye. You naturally use your mind’s eye all the time, especially for keeping your surrounding environment in mind. For example, observe this setup of cubes.

![](./jd-vis-cubes.png)

When counting how many cubes there are in this arrangement, you will probably not only count the cubes you can see with your physical eyes, but also the hidden cubes you can see with your mind’s eye (which in this case acts as a sort of mental x-ray vision). There are 19 visible cubes, and 12 hidden cubes.

![I can see a fuzzy form](./jd-vis-2.png)

At this level of visualization, you are looking through your mind's eye, but you've yet to achieve any sort of definition or significant color in your attempts to visualize. Getting beyond this stage is mainly sheer practice. One visualization exercise you could try is my very slight modification of [Rasznir’s number visualization guide](https://community.tulpa.info/thread-visualization-tulpa-visualization-guide). This exercise involves visualizing a canvas in your mind, and asking your tulpa to draw numbers on each page of the canvas, starting from zero and going up to 100 with each step. Try to maintain visualizing your tulpa writing each number in detail, without losing focus. If you lose focus, start again from zero. I suggest that your tulpa writes these numbers in different colors as well, and that you try to name the color your tulpa used. If correct, move on to the next number. If wrong, start over. The point is for your tulpa to test how accurately you are visualizing color.

![I can see fuzzy blocks of color](./jd-vis-3.png)

At this stage, you've got a foothold but your visualizations are still hazy like a dream you don't really remember well. To get beyond this stage of visualization, you'll want to focus on several different things. For one, you need to start practicing including smaller details in your visualization. Start by scanning your tulpa from head to toe, sequentially zooming closer on smaller areas as if your tulpa was being viewed in Google Maps. Additionally, you'll want to increase your ability to know the exact pose and form of your tulpa. Fuzziness can indicate uncertainty in your visualization, and turning the mind's uncertainties into concrete notions will help decrease the fuzziness as time goes on. To practice this ability, try playing a shape-based puzzle game such as Tetris for an hour or more every day. Eventually your mind will become good at knowing the exact shape of the puzzlefield, which in turn can be applied to your tulpa, reducing fuzziness.

![I can see the whole form, but not the smaller details](./jd-vis-4.png)

At this stage you are competent enough to impose if you’d like, but to really make your tulpa realistic you will need to learn to refine your visualization abilities. One exercise you can try for getting beyond this stage is by going on Google Maps. Start at any location in satellite view, but zoomed out to a point where you can’t actually discern any individual buildings. Spend some time remembering the details of this overhead view. Once you can visualize it in your head well, zoom in a little bit and start to observe the smaller parts that you could not see before. Scan over the area and visualize these as well. Once you can do that, zoom in another iteration and repeat. Go as far as you like remembering details. The goal is to see if you can mentally reconstruct the map in your mind and zoom in and out at will. This exercise can seem a little daunting, so start with small areas and try only zooming in once or twice. After getting good at this, your mind should be capable of visualizing small details in the bigger picture. Additionally you must spend time going over your tulpa’s form and becoming familiar with the smaller details, just as you have done with the maps.

![I can see the smaller details, but struggle to see the whole thing](./jd-vis-5.png)

This is a problem that isn’t as common, where you can see the details of your tulpa, but trying to look at the full form is difficult, often appearing as a collage of details rather than a unified body. The simplest way to work around this problem is to visualize your tulpa from various distances. Visualize your tulpa very far away from you, to the point where she looks like a whole body rather than fragmented details. Ask her to walk towards you until you begin to struggle to see her wholly again. At that point, you’ll have found your threshold for full-body visualization. To stretch this threshold, you’ll simply have to spend some time visualizing your tulpa up-and-down at that distance until the collage effect starts to decrease. Sheer practice is the easiest way I’ve found of mitigating this problem.

![I can see the form, but it seems dark/transparent](./jd-vis-6.png)

You’re nearly a visualization pro, the last step is tearing down the mind barrier that gives your visualizations an uncanny dark or transparent quality. Growing past this stage will have you fully prepared for imposition. While simple visualization practice over time will resolve this problem, it can also be solved through meditation and some general realizations about how you see things. Your physical eyes send visual data to your brain, and your brain makes an image out of it. In essence, you see everything with your brain, not necessarily your eyes. Your visualizations are similar, in that they are interpreted by your brain. You must convince yourself that there is literally no difference between what you can see with your eyes, and what you can visualize, as the end result is entirely constructed in your brain. Your mental image of the world is entirely subject to your conscious will. Every physical object you can see is constructed in your mind only because your eyes react to photons emitted by those objects, and your brain decides to translate that to colors and forms. Every mental object is the same way, but the process is not subject to the laws of the universe. Your brain can translate your imagination into colors and forms in the exact same way. If you can meditate on this train of thought for a while, perhaps you too will believe how subjective reality is. And once you’ve done that, your visualizations will reach the vivid level of quality we’ve been aiming for.

![I can see the form vividly](./jd-vis-7.png)

Congratulations. You can visualize awesomely, and you are fully prepared to try imposition. If you’ve not already done it, try visualizing with your eyes open and compare the quality to your visualizations with your eyes closed. The exercises for open eye visualization are exactly the same as closed eye visualization.

If you are able to achieve certain qualities of visualization, but often find that these qualities only exist for brief moments or flashes and regressing to lower qualities, you will want to try practicing visualization from the lowest quality that you tend to hit.
